@@ -11,42 +11,35 @@ mod token;
 mod ui;
 mod utils;
 
-fn init_app_cli_arguments() -> clap::ArgMatches<'static> {
+fn init_app_cli_arguments() -> clap::ArgMatches {
     clap::App::new("spotify-player")
-        .version("0.5.1")
+        .version("0.5.2")
         .about("A command driven spotify player")
         .author("Thang Pham <phamducthang1234@gmail>")
         .arg(
-            clap::Arg::with_name("theme")
-                .short("t")
+            clap::Arg::new("theme")
+                .short('t')
                 .long("theme")
                 .value_name("THEME")
                 .help("Application theme (default: dracula)")
         )
         .arg(
-            clap::Arg::with_name("config-folder")
-                .short("c")
+            clap::Arg::new("config-folder")
+                .short('c')
                 .long("config-folder")
                 .value_name("FOLDER")
                 .help("Path to the application's config folder (default: $HOME/.config/spotify-player)")
                 .next_line_help(true)
         )
         .arg(
-            clap::Arg::with_name("cache-folder")
-                .short("C")
+            clap::Arg::new("cache-folder")
+                .short('C')
                 .long("cache-folder")
                 .value_name("FOLDER")
                 .help("Path to the application's cache folder (default: $HOME/.cache/spotify-player)")
                 .next_line_help(true)
         )
-        .arg(
-            clap::Arg::with_name("log-file")
-                .short("l")
-                .long("log-file")
-                .value_name("FOLDER")
-                .help("Path to the application's log file (default: $APP_CACHE_FOLDER/spotify-player.log)")
-                .next_line_help(true)
-        ).get_matches()
+        .get_matches()
 }
 
 #[tokio::main]
@@ -76,11 +69,7 @@ async fn main() -> anyhow::Result<()> {
     if std::env::var("RUST_LOG").is_err() {
         std::env::set_var("RUST_LOG", "info")
     }
-    let log_file_path = match args.value_of("log-file") {
-        Some(path) => path.into(),
-        None => cache_folder.join("spotify-player.log"),
-    };
-    let log_file = std::fs::File::create(log_file_path)?;
+    let log_file = std::fs::File::create(cache_folder.join("spotify-player.log"))?;
     tracing_subscriber::fmt::fmt()
         .with_env_filter(tracing_subscriber::EnvFilter::from_default_env())
         .with_ansi(false)
